@@ -11,7 +11,7 @@ import subprocess
 import time
 
 from wiperf_poller.testers.pingtester import PingTester
-from wiperf_poller.helpers.route import inject_static_route
+from wiperf_poller.helpers.route import inject_test_traffic_static_route
 
 class IperfTester(object):
     """
@@ -224,15 +224,18 @@ class IperfTester(object):
                                 data_file, test_name, self.file_logger)
 
                     self.file_logger.info("Iperf3 tcp test ended.")
+                    return True
 
                 else:
                     self.file_logger.error("Error with iperf3 tcp test, check logs")
+                    return False
 
             else:
-                self.file_logger.error("Unable to run iperf test to {} as route to destination not over wireless interface...bypassing test".format(server_hostname))
-                inject_static_route(server_hostname, config_vars, self.file_logger)
+                self.file_logger.error("Unable to run iperf test to {} as route to destination not over correct interface...bypassing test".format(server_hostname))
+                inject_test_traffic_static_route(server_hostname, config_vars, self.file_logger)
                 config_vars['test_issue'] = True
                 config_vars['test_issue_descr'] = "TCP iperf test failure"
+                return False
     
     def run_udp_test(self, config_vars, status_file_obj, check_correct_mode_interface, exporter_obj):
 
@@ -293,12 +296,15 @@ class IperfTester(object):
                 exporter_obj.send_results(config_vars, results_dict, column_headers, data_file, test_name, self.file_logger)
 
                 self.file_logger.info("Iperf3 udp test ended.")
+                return True
 
             else:
                 self.file_logger.error("Error with iperf3 udp test, check logs")
+                return False
 
         else:
-            self.file_logger.error("Unable to run iperf test to {} as route to destination not over wireless interface...bypassing test".format(server_hostname))
-            inject_static_route(server_hostname, config_vars, self.file_logger)
+            self.file_logger.error("Unable to run iperf test to {} as route to destination not over correct interface...bypassing test".format(server_hostname))
+            inject_test_traffic_static_route(server_hostname, config_vars, self.file_logger)
             config_vars['test_issue'] = True
-            config_vars['test_issue_descr'] = "UDP iperf test failure"
\ No newline at end of file
+            config_vars['test_issue_descr'] = "UDP iperf test failure"
+            return False
\ No newline at end of file
